@@ -4,7 +4,7 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '0.92';
+our $VERSION = '0.93';
 
 use utf8;
 use Encode;
@@ -181,7 +181,7 @@ sub auto_load {
     push @columns, $_->{COLUMN_NAME} for @$cols;
 
     # 2. Primary key
-    my $primary_key_sth = $class->dbh->primary_key_info('', '%', $table_name);
+    my $primary_key_sth = $class->dbh->primary_key_info(undef, undef, $table_name);
     my $primary_key_data = $primary_key_sth->fetchrow_hashref;
     my $primary_key = ($primary_key_data) ? $primary_key_data->{COLUMN_NAME} : undef;
 
@@ -248,6 +248,15 @@ sub connect {
     my ($class, $dsn, $username, $password, $options) = @_;
 
     eval { require DBIx::Connector };
+
+    $options->{HandleError} = sub {
+        my ($error_message, $DBI_st) = @_;
+
+        $error_message or return;
+        croak $error_message;
+
+    } if ! exists $options->{HandleError};
+
     if ($@) {
         $connector = ActiveRecord::Simple::Connect->new($dsn, $username, $password, $options);
         $connector->db_connect;
@@ -852,6 +861,7 @@ sub AUTOLOAD {
     my $sub = $AUTOLOAD; $sub =~ s/.*:://g;
     my $error = "Unknown method: $sub";
 
+    croak "Error while executing '$sub' method, '$self' is not a valid (blessed) object." unless blessed $self;
     croak "Undefined object for method $sub: must be not undef" unless $param;
 
     croak $error unless $self->can('_get_relations');
@@ -883,8 +893,6 @@ sub AUTOLOAD {
 
 ### Private
 
-
-
 1;
 
 __END__;
